==> stam_1.4.0.tar.gz: stam/R/07_eval.R <==
################################################################################
#
#   08_stamEval.R
#
#   Holds evaluation data for storage and HTML reporting.
#
#   written by Claudio Lottaz (COMPDIAG-MPI-MG), in August 2004
#
################################################################################
#
#   Class Definition and Constructor
#

setClass("stamEval", 
         representation(chip    = "character",
                        exprs   = "matrix",
                        cv      = "stamCV",
                        fit     = "stamFit",
                        pred    = "stamPrediction",
                        testset = "numeric"))

setMethod("initialize", "stamEval", 
  function(.Object, exprs, cv, fit, pred, testset=NULL) {
    .Object@exprs     <- exprs
    .Object@chip      <- cv@chip
    .Object@cv        <- cv
    .Object@fit       <- fit
    .Object@pred      <- pred
    .Object@testset   <- testset
    return(.Object)
  }
)

################################################################################
#
#   Reports and HTML
#

setMethod("writeHTML", "stamEval",
  function(x, aclass=NULL, minspec=NULL, minsens=0.1, maxsens=1.0, ...) {
    cat(" - Writing report...\n")

    # table of contents
    catHTML(HR(),
            P(UL(LI(HREF("Evaluation information", url="#evalinfo")),
                 LI(HREF("Annotation information", url="#netinfo")),
                 LI(HREF("Cross validation information", url="#cvinfo")),
                 LI(HREF("Model fit information", url="#fitinfo")),
                 LI(HREF("Prediction information", url="#predinfo")),
                 LI(HREF("Details on nodes", url="#nodeinfo")))))
    
    train <- table(x@cv@sample.classes)
    test <- table(x@pred@cls[x@testset])

    # Evaluation information
    catHTML(HR(), NAME("evalinfo"), H2("Information on Evaluation"), 
            P(TABLE(cellpadding="5", #cellspacing="5", border="5", 
              TR(valign="top", 
                 TH(align="right", bgcolor="lightgreen", "Total number of samples:"), 
                 TD(ncol(x@exprs))),
              TR(valign="top", 
                 TH(align="right", bgcolor="lightgreen", "Training samples:"), 
                 TD(sum(train), " (", toString(paste(train, "from", names(train))), ")")),
              TR(valign="top", 
                 TH(align="right", bgcolor="lightgreen", "Test samples:"), 
                 TD(sum(test), "(", toString(paste(test, "from", names(test))), ")")),
              TR(valign="top", 
                 TH(align="right", bgcolor="lightgreen", "Focus on class:"), 
                 TD(aclass)),
              TR(valign="top", 
                 TH(align="right", bgcolor="lightgreen", "Data frm chip:"), 
                 TD(toString(x@cv@chip))),
              TR(valign="top", 
                 TH(align="right", bgcolor="lightgreen", "Start node:"), 
                 TD(x@cv@root, "(", getGOterm(x@cv@root), ")")))))


    # Information from subparts
    writeHTML(x@cv, aclass=aclass, delta=x@fit@best.delta)
    writeHTML(x@fit, aclass=aclass, exprs=x@exprs[,x@cv@sample.classes], 
              nonodes=TRUE, write.form=!is.null(getOption("stam.write.forms")))
    writeHTML(x@pred, aclass=aclass, minspec=minspec, minsens=minsens, maxsens=maxsens, 
              nonodes=TRUE, write.form=!is.null(getOption("stam.write.forms")))

    # Information about root node, other nodes i separate files
    catHTML(HR(), NAME("nodeinfo"), H2("Details on Nodes"))
    .stam.allnodes <<- x@fit@nodes
    .stam.GOids <<- new.env(hash=TRUE)
    for (i in 1:length(.stam.allnodes)) 
      assign(.stam.allnodes[[i]]@ID, i, .stam.GOids)
    if (!exists(".stam.cv", envir=.GlobalEnv)) .stam.cv <<- x@cv
    .stam.exprs <<- x@exprs
    i <- length(x@fit@nodes)
    writeHTML(x@fit@nodes[[i]], sepfiles=TRUE)
    stam.nodePerformanceHTML(x@fit,  i, "Performance on training data")      
    stam.nodePerformanceHTML(x@pred, i, "Performance on test data")
    stam.nodePredictHTML(x@pred, i)
    rm(.stam.exprs, .stam.cv, .stam.allnodes, .stam.GOids, envir=.GlobalEnv)
  }
)


#
#   End of File
#
###############################################################################

==> stam_1.8.0.tar.gz: stam/R/07_eval.R <==
################################################################################
#
#   08_stamEval.R
#
#   Holds evaluation data for storage and HTML reporting.
#
#   written by Claudio Lottaz (COMPDIAG-MPI-MG), in August 2004
#
################################################################################
#
#   Class Definition and Constructor
#

setClass("stamEval", 
         representation(chip    = "character",
                        exprs   = "matrix",
                        cv      = "stamCV",
                        fit     = "stamFit",
                        pred    = "stamPrediction",
                        testset = "numeric"))

setMethod("initialize", "stamEval", 
  function(.Object, exprs, cv, fit, pred, testset=NULL) {
    .Object@exprs     <- exprs
    .Object@chip      <- cv@chip
    .Object@cv        <- cv
    .Object@fit       <- fit
    .Object@pred      <- pred
    .Object@testset   <- testset
    return(.Object)
  }
)

################################################################################
#
#   Reports and HTML
#

setMethod("writeHTML", "stamEval",
  function(x, aclass=NULL, minspec=NULL, minsens=0.1, maxsens=1.0, ...) {
    cat(" - Writing report...\n")

    # table of contents
    catHTML(HR(),
            P(UL(LI(HREF("Evaluation information", url="#evalinfo")),
                 LI(HREF("Annotation information", url="#netinfo")),
                 LI(HREF("Cross validation information", url="#cvinfo")),
                 LI(HREF("Model fit information", url="#fitinfo")),
                 LI(HREF("Prediction information", url="#predinfo")),
                 LI(HREF("Details on nodes", url="#nodeinfo")))))
    
    train <- table(x@cv@sample.classes)
    test <- table(x@pred@cls[x@testset])

    # Evaluation information
    catHTML(HR(), NAME("evalinfo"), H2("Information on Evaluation"), 
            P(TABLE(cellpadding="5", #cellspacing="5", border="5", 
              TR(valign="top", 
                 TH(align="right", bgcolor="lightgreen", "Total number of samples:"), 
                 TD(ncol(x@exprs))),
              TR(valign="top", 
                 TH(align="right", bgcolor="lightgreen", "Training samples:"), 
                 TD(sum(train), " (", toString(paste(train, "from", names(train))), ")")),
              TR(valign="top", 
                 TH(align="right", bgcolor="lightgreen", "Test samples:"), 
                 TD(sum(test), "(", toString(paste(test, "from", names(test))), ")")),
              TR(valign="top", 
                 TH(align="right", bgcolor="lightgreen", "Focus on class:"), 
                 TD(aclass)),
              TR(valign="top", 
                 TH(align="right", bgcolor="lightgreen", "Data frm chip:"), 
                 TD(toString(x@cv@chip))),
              TR(valign="top", 
                 TH(align="right", bgcolor="lightgreen", "Start node:"), 
                 TD(x@cv@root, "(", getGOterm(x@cv@root), ")")))))


    # Information from subparts
    writeHTML(x@cv, aclass=aclass, delta=x@fit@best.delta)
    writeHTML(x@fit, aclass=aclass, exprs=x@exprs[,x@cv@sample.classes], 
              nonodes=TRUE, write.form=!is.null(getOption("stam.write.forms")))
    writeHTML(x@pred, aclass=aclass, minspec=minspec, minsens=minsens, maxsens=maxsens, 
              nonodes=TRUE, write.form=!is.null(getOption("stam.write.forms")))

    # Information about root node, other nodes i separate files
    catHTML(HR(), NAME("nodeinfo"), H2("Details on Nodes"))
    stam.env[["allnodes"]] <- x@fit@nodes
    stam.env[["GOids"]] <- new.env(hash=TRUE)
    for (i in 1:length(stam.env[["allnodes"]])) 
      assign(stam.env[["allnodes"]][[i]]@ID, i, stam.env[["GOids"]])
    if (!exists("cv", envir=stam.env)) stam.env[["cv"]] <- x@cv
    stam.env[["exprs"]] <- x@exprs
    i <- length(x@fit@nodes)
    writeHTML(x@fit@nodes[[i]], sepfiles=TRUE)
    stam.nodePerformanceHTML(x@fit,  i, "Performance on training data")      
    stam.nodePerformanceHTML(x@pred, i, "Performance on test data")
    stam.nodePredictHTML(x@pred, i)
    rm("cv", "exprs", "allnodes", "GOids", envir=stam.env)
  }
)


#
#   End of File
#
###############################################################################
